@@ -1,7 +1,7 @@
 // -*- mode: c++; tab-width: 4; indent-tabs-mode: t; eval: (progn (c-set-style "stroustrup") (c-set-offset 'innamespace 0)); -*-
 // vi:set ts=4 sts=4 sw=4 noet :
 //
-// Copyright 2010, 2011 wkhtmltopdf authors
+// Copyright 2010-2020 wkhtmltopdf authors
 //
 // This file is part of wkhtmltopdf.
 //
@@ -146,7 +146,7 @@ void PdfConverterPrivate::beginConvert() {
 
 #ifndef __EXTENSIVE_WKHTMLTOPDF_QT_HACK__
 	if (objects.size() > 1) {
-		emit out.error("This version of wkhtmltopdf is build against an unpatched version of QT, and does not support more then one input document.");
+		emit out.error("This version of wkhtmltopdf is built against an unpatched version of QT, and does not support more than one input document.");
 		fail();
 		return;
 	}
@@ -887,8 +887,13 @@ void PdfConverterPrivate::beginPrintObject(PageObject & obj) {
 		endPrintObject(objects[obj.number-1]);
 	currentObject = obj.number;
 
+	if (!obj.loaderObject || obj.loaderObject->skip)
+		return;
+
 	QWebPrinter *webPrinter = objects[currentObject].web_printer;
-	if (!obj.loaderObject || obj.loaderObject->skip || webPrinter == 0) return;
+	if (webPrinter == 0)
+		webPrinter = objects[currentObject].web_printer = \
+			new QWebPrinter(obj.page->mainFrame(), printer, *painter);
 
 	QPalette pal = obj.loaderObject->page.palette();
 	pal.setBrush(QPalette::Base, Qt::transparent);
