@@ -1,7 +1,7 @@
 // -*- mode: c++; tab-width: 4; indent-tabs-mode: t; eval: (progn (c-set-style "stroustrup") (c-set-offset 'innamespace 0)); -*-
 // vi:set ts=4 sts=4 sw=4 noet :
 //
-// Copyright 2010, 2011 wkhtmltopdf authors
+// Copyright 2010-2020 wkhtmltopdf authors
 //
 // This file is part of wkhtmltopdf.
 //
@@ -51,7 +51,7 @@ void PdfCommandLineParser::outputSynopsis(Outputter * o) const {
 			"the output document in the order they are specified on the command line, options can "
 			"be specified on a per object basis or in the global options area. Options from the ");
 	o->sectionLink("Global Options");
-	o->text(" section can only be placed in the global options area");
+	o->text(" section can only be placed in the global options area.");
 	o->endParagraph();
 
 	o->paragraph("A page objects puts the content of a single webpage into the output document.");
@@ -163,7 +163,7 @@ void PdfCommandLineParser::outputPageBreakDoc(Outputter * o) const {
 void PdfCommandLineParser::outputHeaderFooterDoc(Outputter * o) const {
 	o->beginSection("Footers And Headers");
 	o->paragraph("Headers and footers can be added to the document by the --header-* and --footer* "
-				 "arguments respectfully.  In header and footer text string supplied to e.g. --header-left, "
+				 "arguments respectively.  In header and footer text string supplied to e.g. --header-left, "
 				 "the following variables will be substituted.");
 	o->verbatim(
 " * [page]       Replaced by the number of the pages currently being printed\n"
@@ -180,7 +180,7 @@ void PdfCommandLineParser::outputHeaderFooterDoc(Outputter * o) const {
 " * [sitepage]   Replaced by the number of the page in the current site being converted\n"
 " * [sitepages]  Replaced by the number of pages in the current site being converted\n"
 "\n");
-	o->paragraph("As an example specifying --header-right \"Page [page] of [toPage]\", "
+	o->paragraph("As an example specifying --header-right \"Page [page] of [topage]\", "
 				 "will result in the text \"Page x of y\" where x is the number of the "
 				 "current page and y is the number of the last page, to appear in the upper "
 				 "left corner in the document.");
@@ -229,16 +229,16 @@ void PdfCommandLineParser::outputTableOfContentDoc(Outputter * o) const {
 	o->beginSection("Table Of Contents");
 	o->paragraph("A table of contents can be added to the document by adding a toc object "
 				 "to the command line. For example:");
-	o->verbatim("wkhtmltopdf toc http://qt-project.org/doc/qt-4.8/qstring.html qstring.pdf\n");
+	o->verbatim("wkhtmltopdf toc https://qt-project.org/doc/qt-4.8/qstring.html qstring.pdf\n");
 	o->paragraph("The table of contents is generated based on the H tags in the input "
 				 "documents. First a XML document is generated, then it is converted to "
 				 "HTML using XSLT.");
 	o->paragraph("The generated XML document can be viewed by dumping it to a file using "
 				 "the --dump-outline switch. For example:");
-	o->verbatim("wkhtmltopdf --dump-outline toc.xml http://qt-project.org/doc/qt-4.8/qstring.html qstring.pdf\n");
+	o->verbatim("wkhtmltopdf --dump-outline toc.xml https://qt-project.org/doc/qt-4.8/qstring.html qstring.pdf\n");
 	o->paragraph("The XSLT document can be specified using the --xsl-style-sheet switch. "
 				 "For example:");
-	o->verbatim("wkhtmltopdf toc --xsl-style-sheet my.xsl http://qt-project.org/doc/qt-4.8/qstring.html qstring.pdf\n");
+	o->verbatim("wkhtmltopdf toc --xsl-style-sheet my.xsl https://qt-project.org/doc/qt-4.8/qstring.html qstring.pdf\n");
 	o->paragraph("The --dump-default-toc-xsl switch can be used to dump the default "
 				 "XSLT style sheet to stdout. This is a good start for writing your "
 				 "own style sheet");
@@ -291,7 +291,7 @@ void PdfCommandLineParser::outputContact(Outputter * o) const {
 	o->beginSection("Contact");
 	o->beginParagraph();
 	o->text("If you experience bugs or want to request new features please visit ");
-	o->link("https://github.com/wkhtmltopdf/wkhtmltopdf/issues");
+	o->link("https://wkhtmltopdf.org/support.html");
 	o->endParagraph();
 	o->endSection();
 }
@@ -319,8 +319,8 @@ void PdfCommandLineParser::outputArgsFromStdin(Outputter * o) const {
 				 "will act as a separate invocation of wkhtmltopdf, with the arguments specified "
 				 "on the given line combined with the arguments given to wkhtmltopdf");
 	o->paragraph("For example one could do the following:");
-	o->verbatim("echo \"http://qt-project.org/doc/qt-4.8/qapplication.html qapplication.pdf\" >> cmds\n"
-				"echo \"cover google.com http://en.wikipedia.org/wiki/Qt_(software) qt.pdf\" >> cmds\n"
+	o->verbatim("echo \"https://qt-project.org/doc/qt-4.8/qapplication.html qapplication.pdf\" >> cmds\n"
+				"echo \"cover google.com https://en.wikipedia.org/wiki/Qt_(software) qt.pdf\" >> cmds\n"
 				"wkhtmltopdf --read-args-from-stdin --book < cmds\n");
 	o->endSection();
 }
@@ -350,10 +350,10 @@ void PdfCommandLineParser::outputInstallation(Outputter * o) const {
 void PdfCommandLineParser::outputPageSizes(Outputter * o) const {
 	o->beginSection("Page sizes");
 	o->beginParagraph();
-	o->text("The default page size of the rendered document is A4, but using this --page-size option"
-			"this can be changed to almost anything else, such as: A3, Letter and Legal.  "
+	o->text("The default page size of the rendered document is A4, but by using the --page-size "
+			"option this can be changed to almost anything else, such as: A3, Letter and Legal.  "
 			"For a full list of supported pages sizes please see ");
-	o->link("http://qt-project.org/doc/qt-4.8/qprinter.html#PaperSize-enum");
+	o->link("https://qt-project.org/doc/qt-4.8/qprinter.html#PaperSize-enum");
 	o->text(".");
 	o->endParagraph();
 	o->paragraph("For a more fine grained control over the page size the "
@@ -369,11 +369,11 @@ void PdfCommandLineParser::outputExamples(Outputter * o) const {
 	o->beginSection("Examples");
 	o->paragraph("This section presents a number of examples of how to invoke wkhtmltopdf.");
 	o->paragraph("To convert a remote HTML file to PDF:");
-	o->verbatim("wkhtmltopdf http://www.google.com google.pdf\n");
+	o->verbatim("wkhtmltopdf https://www.google.com google.pdf\n");
 	o->paragraph("To convert a local HTML file to PDF:");
 	o->verbatim("wkhtmltopdf my.html my.pdf\n");
 	o->paragraph("Produce the eler2.pdf sample file:");
-	o->verbatim("wkhtmltopdf -H  http://geekz.co.uk/lovesraymond/archive/eler-highlights-2008 eler2.pdf\n");
+	o->verbatim("wkhtmltopdf -H  https://geekz.co.uk/lovesraymond/archive/eler-highlights-2008 eler2.pdf\n");
 	o->paragraph("Printing a book with a table of contents:");
 	o->verbatim("wkhtmltopdf -H cover cover.html toc chapter1.html chapter2.html chapter3.html book.pdf\n");
 	o->endSection();
