@@ -1,7 +1,7 @@
 // -*- mode: c++; tab-width: 4; indent-tabs-mode: t; eval: (progn (c-set-style "stroustrup") (c-set-offset 'innamespace 0)); -*-
 // vi:set ts=4 sts=4 sw=4 noet :
 //
-// Copyright 2010, 2011 wkhtmltopdf authors
+// Copyright 2010-2020 wkhtmltopdf authors
 //
 // This file is part of wkhtmltopdf.
 //
@@ -38,7 +38,7 @@ void CommandLineParserBase::outputName(Outputter * o) const {
 */
 void CommandLineParserBase::outputLicense(Outputter * o) const {
 	o->beginSection("License");
-	o->paragraph("Copyright (c) 2010-2014 wkhtmltopdf authors");
+	o->paragraph("Copyright (c) 2010-2020 wkhtmltopdf authors");
 	QFile file(":/LICENSE");
 	file.open(QIODevice::ReadOnly | QIODevice::Text);
 	QTextStream stream(&file);
@@ -67,7 +67,7 @@ void CommandLineParserBase::outputStaticProblems(Outputter * o) const {
 	o->beginSection("Static version");
 	o->beginParagraph();
 	o->text("On the wkhtmltopdf website you can download a static version of wkhtmltopdf ");
-	o->link("http://wkhtmltopdf.org/downloads.html");
+	o->link("https://wkhtmltopdf.org/downloads.html");
 	o->text(". This static binary will work on most systems and comes with a build in patched QT.");
 	o->endParagraph();
 
